==> ud2_0.zip: resources/wordoku/wordoku_resources/js/ardoratablaCFG.js <==
//Creado con Ardora - www.webardora.net
//bajo licencia Attribution-NonCommercial-NoDerivatives 4.0 International (CC BY-NC-ND 4.0)
//para otros usos contacte con el autor
var timeAct=360; timeIni=360; timeBon=0;
var successes=0; successesMax=1; attempts=0; attemptsMax=5;
var score=0; scoreMax=10; scoreInc=10; scoreDec=1
var typeGame=0;
var tiTime=false;
var tiTimeType=0;
var tiButtonTime=false;
var textButtonTime="Start";
var tiSuccesses=false;
var tiAttempts=false;
var tiScore=true;
var startTime;
var colorBack="#FFFFFF"; colorButton="#0086FF"; colorText="#000000"; colorSele="#72A2C9";
var goURLNext=false; goURLRepeat=false;tiAval=false;
var scoOk=0; scoWrong=0; scoOkDo=1; scoWrongDo=1; scoMessage=""; scoPtos=10;
var fMenssage="Verdana, Geneva, sans-serif";
var fActi="Verdana, Geneva, sans-serif";
var fEnun="Verdana, Geneva, sans-serif";
var timeOnMessage=3; messageOk="FANTASTIC!!"; messageTime=""; messageError="FALSE!!"; messageErrorG="FALSE!!"; messageAttempts="START AGAIN!!"; isShowMessage=false;
var urlOk=""; urlTime=""; urlError=""; urlAttempts="";
var goURLOk="_blank"; goURLTime="_blank"; goURLAttempts="_blank"; goURLError="_blank"; 
borderOk="#008000"; borderTime="#FF0000";borderError="#FF0000"; borderAttempts="#FF0000";
var d=[[1,0,1,0,1,1,1,1,0],[0,1,0,0,0,0,0,1,1],[1,1,0,1,0,1,0,1,0],[1,0,1,0,1,0,1,0,0],[0,1,0,0,0,0,0,0,0],[1,0,1,1,1,0,0,1,1],[1,0,1,1,0,1,0,1,0],[0,1,0,1,1,1,1,0,0],[0,0,0,1,0,1,0,1,1]];
var vCell=[["1","1","1","0","1","1","1","1","0"],["1","1","0","0","0","0","0","1","1"],["1","1","0","1","0","1","0","1","0"],["1","0","1","0","1","0","1","0","0"],["0","1","0","0","0","0","0","0","0"],["1","0","1","1","1","0","0","1","1"],["1","0","1","1","0","1","0","1","0"],["0","1","0","1","1","1","1","0","0"],["0","0","0","1","0","1","0","1","1"]];
var a0Cell=[["SQ","Ug","WA","Tg","RQ","Rw","UA","TA","Tw"],["UA","Rw","Tw","TA","WA","Ug","RQ","Tg","SQ"],["Tg","RQ","TA","SQ","UA","Tw","Ug","WA","Rw"],["RQ","WA","UA","Rw","TA","SQ","Tw","Ug","Tg"],["TA","Tg","Ug","UA","Tw","RQ","SQ","Rw","WA"],["Rw","Tw","SQ","WA","Ug","Tg","TA","UA","RQ"],["Ug","UA","Rw","Tw","SQ","WA","Tg","RQ","TA"],["WA","SQ","RQ","Ug","Tg","TA","Rw","Tw","UA"],["Tw","TA","Tg","RQ","Rw","UA","WA","SQ","Ug"]];
var c=[[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1]];
var c1=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];
var c2=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];
var c3=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];
var a1Cell=[["SQ","Ug","WA","Tg","RQ","Rw","UA","TA","Tw"],["UA","Rw","Tw","TA","WA","Ug","RQ","Tg","SQ"],["Tg","RQ","TA","SQ","UA","Tw","Ug","WA","Rw"],["RQ","WA","UA","Rw","TA","SQ","Tw","Ug","Tg"],["TA","Tg","Ug","UA","Tw","RQ","SQ","Rw","WA"],["Rw","Tw","SQ","WA","Ug","Tg","TA","UA","RQ"],["Ug","UA","Rw","Tw","SQ","WA","Tg","RQ","TA"],["WA","SQ","RQ","Ug","Tg","TA","Rw","Tw","UA"],["Tw","TA","Tg","RQ","Rw","UA","WA","SQ","Ug"]];
var a2Cell=[["SQ","Ug","WA","Tg","RQ","Rw","UA","TA","Tw"],["UA","Rw","Tw","TA","WA","Ug","RQ","Tg","SQ"],["Tg","RQ","TA","SQ","UA","Tw","Ug","WA","Rw"],["RQ","WA","UA","Rw","TA","SQ","Tw","Ug","Tg"],["TA","Tg","Ug","UA","Tw","RQ","SQ","Rw","WA"],["Rw","Tw","SQ","WA","Ug","Tg","TA","UA","RQ"],["Ug","UA","Rw","Tw","SQ","WA","Tg","RQ","TA"],["WA","SQ","RQ","Ug","Tg","TA","Rw","Tw","UA"],["Tw","TA","Tg","RQ","Rw","UA","WA","SQ","Ug"]];
var a3Cell=[["SQ","Ug","WA","Tg","RQ","Rw","UA","TA","Tw"],["UA","Rw","Tw","TA","WA","Ug","RQ","Tg","SQ"],["Tg","RQ","TA","SQ","UA","Tw","Ug","WA","Rw"],["RQ","WA","UA","Rw","TA","SQ","Tw","Ug","Tg"],["TA","Tg","Ug","UA","Tw","RQ","SQ","Rw","WA"],["Rw","Tw","SQ","WA","Ug","Tg","TA","UA","RQ"],["Ug","UA","Rw","Tw","SQ","WA","Tg","RQ","TA"],["WA","SQ","RQ","Ug","Tg","TA","Rw","Tw","UA"],["Tw","TA","Tg","RQ","Rw","UA","WA","SQ","Ug"]];
var wordsGame="d29yZG9rdQ"; wordsStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
function giveZindex(typeElement){var valueZindex=0; capas=document.getElementsByTagName(typeElement);
for (i=0;i<capas.length;i++){if (parseInt($(capas[i]).css("z-index"),10)>valueZindex){valueZindex=parseInt($(capas[i]).css("z-index"),10);}}return valueZindex;}
var cols=9; var rows=9;var showC=true;

==> ud4_0.zip: resources/wordoku/wordoku_resources/js/ardoratablaCFG.js <==
//Creado con Ardora - www.webardora.net
//bajo licencia Attribution-NonCommercial-NoDerivatives 4.0 International (CC BY-NC-ND 4.0)
//para otros usos contacte con el autor
var timeAct=360; timeIni=360; timeBon=0;
var successes=0; successesMax=1; attempts=0; attemptsMax=5;
var score=0; scoreMax=10; scoreInc=10; scoreDec=1
var typeGame=0;
var tiTime=false;
var tiTimeType=0;
var tiButtonTime=false;
var textButtonTime="Start";
var tiSuccesses=false;
var tiAttempts=false;
var tiScore=true;
var startTime;
var colorBack="#FFFFFF"; colorButton="#CC9900"; colorText="#000000"; colorSele="#808040";
var goURLNext=false; goURLRepeat=false;tiAval=false;
var scoOk=0; scoWrong=0; scoOkDo=1; scoWrongDo=1; scoMessage=""; scoPtos=10;
var fMenssage="Verdana, Geneva, sans-serif";
var fActi="Verdana, Geneva, sans-serif";
var fEnun="Verdana, Geneva, sans-serif";
var timeOnMessage=3; messageOk="FANTASTIC!!"; messageTime=""; messageError="FALSE!!"; messageErrorG="FALSE!!"; messageAttempts="START AGAIN!!"; isShowMessage=false;
var urlOk=""; urlTime=""; urlError=""; urlAttempts="";
var goURLOk="_blank"; goURLTime="_blank"; goURLAttempts="_blank"; goURLError="_blank"; 
borderOk="#008000"; borderTime="#FF0000";borderError="#FF0000"; borderAttempts="#FF0000";
var d=[[1,0,1,0,1,1,1,1,0],[0,1,0,0,0,0,0,1,1],[1,1,0,1,0,1,0,1,0],[1,0,1,0,1,0,1,0,0],[0,1,0,0,0,0,0,0,0],[1,0,1,1,1,0,0,1,1],[1,0,1,1,0,1,0,1,0],[0,1,0,1,1,1,1,0,0],[0,0,0,1,0,1,0,1,1]];
var vCell=[["1","1","1","0","1","1","1","1","0"],["1","1","0","0","0","0","0","1","1"],["1","1","0","1","0","1","0","1","0"],["1","0","1","0","1","0","1","0","0"],["0","1","0","0","0","0","0","0","0"],["1","0","1","1","1","0","0","1","1"],["1","0","1","1","0","1","0","1","0"],["0","1","0","1","1","1","1","0","0"],["0","0","0","1","0","1","0","1","1"]];
var a0Cell=[["RQ","Vg","SQ","Ug","RA","WQ","Uw","Qw","Tw"],["Uw","WQ","Tw","Qw","SQ","Vg","RA","Ug","RQ"],["Ug","RA","Qw","RQ","Uw","Tw","Vg","SQ","WQ"],["RA","SQ","Uw","WQ","Qw","RQ","Tw","Vg","Ug"],["Qw","Ug","Vg","Uw","Tw","RA","RQ","WQ","SQ"],["WQ","Tw","RQ","SQ","Vg","Ug","Qw","Uw","RA"],["Vg","Uw","WQ","Tw","RQ","SQ","Ug","RA","Qw"],["SQ","RQ","RA","Vg","Ug","Qw","WQ","Tw","Uw"],["Tw","Qw","Ug","RA","WQ","Uw","SQ","RQ","Vg"]];
var c=[[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1],[1,1,1,1,1,1,1,1,1]];
var c1=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];
var c2=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];
var c3=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];
var a1Cell=[["RQ","Vg","SQ","Ug","RA","WQ","Uw","Qw","Tw"],["Uw","WQ","Tw","Qw","SQ","Vg","RA","Ug","RQ"],["Ug","RA","Qw","RQ","Uw","Tw","Vg","SQ","WQ"],["RA","SQ","Uw","WQ","Qw","RQ","Tw","Vg","Ug"],["Qw","Ug","Vg","Uw","Tw","RA","RQ","WQ","SQ"],["WQ","Tw","RQ","SQ","Vg","Ug","Qw","Uw","RA"],["Vg","Uw","WQ","Tw","RQ","SQ","Ug","RA","Qw"],["SQ","RQ","RA","Vg","Ug","Qw","WQ","Tw","Uw"],["Tw","Qw","Ug","RA","WQ","Uw","SQ","RQ","Vg"]];
var a2Cell=[["RQ","Vg","SQ","Ug","RA","WQ","Uw","Qw","Tw"],["Uw","WQ","Tw","Qw","SQ","Vg","RA","Ug","RQ"],["Ug","RA","Qw","RQ","Uw","Tw","Vg","SQ","WQ"],["RA","SQ","Uw","WQ","Qw","RQ","Tw","Vg","Ug"],["Qw","Ug","Vg","Uw","Tw","RA","RQ","WQ","SQ"],["WQ","Tw","RQ","SQ","Vg","Ug","Qw","Uw","RA"],["Vg","Uw","WQ","Tw","RQ","SQ","Ug","RA","Qw"],["SQ","RQ","RA","Vg","Ug","Qw","WQ","Tw","Uw"],["Tw","Qw","Ug","RA","WQ","Uw","SQ","RQ","Vg"]];
var a3Cell=[["RQ","Vg","SQ","Ug","RA","WQ","Uw","Qw","Tw"],["Uw","WQ","Tw","Qw","SQ","Vg","RA","Ug","RQ"],["Ug","RA","Qw","RQ","Uw","Tw","Vg","SQ","WQ"],["RA","SQ","Uw","WQ","Qw","RQ","Tw","Vg","Ug"],["Qw","Ug","Vg","Uw","Tw","RA","RQ","WQ","SQ"],["WQ","Tw","RQ","SQ","Vg","Ug","Qw","Uw","RA"],["Vg","Uw","WQ","Tw","RQ","SQ","Ug","RA","Qw"],["SQ","RQ","RA","Vg","Ug","Qw","WQ","Tw","Uw"],["Tw","Qw","Ug","RA","WQ","Uw","SQ","RQ","Vg"]];
var wordsGame="d29yZG9rdQ"; wordsStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
function giveZindex(typeElement){var valueZindex=0; capas=document.getElementsByTagName(typeElement);
for (i=0;i<capas.length;i++){if (parseInt($(capas[i]).css("z-index"),10)>valueZindex){valueZindex=parseInt($(capas[i]).css("z-index"),10);}}return valueZindex;}
var cols=9; var rows=9;var showC=true;
